#
# spec file for package libao
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname  4
# Check configure.ac for the plugin versioning
%define plugver 4
%define my_provides /tmp/my-provides
Name:           libao
Version:        1.2.0
Release:        5.3
Summary:        A Cross-Platform Audio Output Library
License:        GPL-2.0+
Group:          System/Libraries
Url:            http://www.xiph.org/ao/
Source:         http://downloads.xiph.org/releases/ao/%{name}-%{version}.tar.gz
Patch1:         libao-ocloexec.patch
BuildRequires:  alsa-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libpulse-devel
BuildRequires:  libtool
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Obsoletes:      plugin4-esd

%description
Libao is a cross-platform audio output library.

%package -n libao%{soname}
Summary:        A Cross-Platform Audio Output Library
Group:          System/Libraries
Requires:       libao-plugins%{plugver}
# libao was last used in openSUSE 11.3
Provides:       libao = 1.1.0
Obsoletes:      libao < 1.1.0

%description -n libao%{soname}
Libao is a cross-platform audio output library.

%package plugins%{plugver}
Summary:        Main output plugins for libao
Group:          System/Libraries

%description plugins%{plugver}
This package contains the main output plugins for libao.

%package devel
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libao%{soname} = %{version}

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%prep
%setup -q

# setup libdir properly
sed -i "s:/lib:/%{_lib}:g" ao.m4

%patch1

%build
autoreconf -fiv
%configure \
	--enable-alsa \
	--enable-alsa-mmap \
	--enable-nas \
	--enable-pulse \
	--disable-static \
	--disable-arts \
	--disable-esd
make %{?_smp_mflags}

%install
%make_install docdir=%{_docdir}/%{name}-devel
find %{buildroot} -type f -name "*.la" -delete -print
# exclude plugins from the provide-list
cat << EOF > %{my_provides}
grep -v %{_libdir}/ao/ | %{__find_provides}
EOF
chmod 755 %{my_provides}
%define _use_internal_dependency_generator 0
%define __find_provides %{my_provides}

%post -n libao%{soname} -p /sbin/ldconfig

%postun -n libao%{soname} -p /sbin/ldconfig

%files -n libao%{soname}
%defattr(0644,root,root,0755)
%doc AUTHORS CHANGES COPYING README TODO
%{_libdir}/libao.so.%{soname}*
%dir %{_libdir}/ao
%dir %{_libdir}/ao/plugins-%{plugver}

%files plugins%{plugver}
%defattr(0644,root,root,0755)
%{_libdir}/ao/plugins-%{plugver}/libalsa.so
%{_libdir}/ao/plugins-%{plugver}/liboss.so
%{_libdir}/ao/plugins-%{plugver}/libpulse.so

%files devel
%defattr(-,root,root)
%{_docdir}/%{name}-devel
%{_mandir}/*/*
%{_includedir}/ao
%{_libdir}/libao.so
%{_libdir}/ckport
%{_datadir}/aclocal/*.m4
%{_libdir}/pkgconfig/*.pc

%changelog
* Thu May 15 2014 tchvatal@suse.com
- Version bump to 1.2.0:
  - Added missing ao_file_extension() (see Trac #1841)
  - Fixed memory leak in ao_shutdown() (see Trac #1799)
  - Updated manpage libao.conf.5 (see Trac #1822)
  - Corrected doc/ao_play.html (see Trac #1808)
  - Latency adjustments
  - Implement PulseAudio client_name (see Trac #1924)
  - Other ALSA, Pulse, Roar, sndio and MacOS driver improvements
- Disable esd module, Gnome is not using that for ages and moved to
  pulse anyway.
- Drop patch lib64.dif and replace it by simple sed that works
  more straight-forward.
* Thu Apr 11 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Mon Dec 26 2011 crrodriguez@opensuse.org
- Use O_CLOEXEC in shared library
- Remove aRts plugin, which is dead since 2004.
- remove _service file
* Thu May 12 2011 dmueller@suse.de
- fix missing obsoletes for 32bit baselibs package
* Thu May  5 2011 dmueller@suse.de
- fix provides/obsoletes
* Sun May  1 2011 toddrme2178@gmail.com
- Added 32bit compatibility libraries
* Thu Feb 24 2011 reddwarf@opensuse.org
- update to version 1.1.0
  * Add autofoo ld symbol versioning to build system
  * Update Roar driver to latest API
  * Fix Roar driver to not block on SLP lookup during probe
  * Improve/correct latency setup in ALSA (see Trac #1762)
  * Add missing ctype.h header in build (see Trac #1760)
  * Move toward more consistent option naming across drivers
  * Correct ao_example.c source to not pass dangling pointer for
  the matrix argument.
  * Add 24 bit playback to Pulse plugin
  * Fix 24 bit playback in ALSA plugin
  * Fix segfaults when closing a driver that did not successfully
  open.
  * Fix compilation of sndio plugin
- Remove ao-pulse-fixes.patch, libao-missing_headers.diff and
  libao-alsa-fix.diff since were applied by upstream
- Remove libao-pulse Provides/Obsoletes from libao-plugins4
  subpackage since the new pulse plugin isn't the same than the
  old one.
* Fri Feb 11 2011 remur@gmx.net
- Add ao-pulse-fixes.patch to fix https://trac.xiph.org/ticket/1689
    libao not working correctly with pulse audio
* Wed Dec 15 2010 vuntz@opensuse.org
- Add libao-pulse Provides/Obsoletes to libao-plugins4 subpackage
  since it now provides the pulse plugin.
* Sat Dec 11 2010 reddwarf@opensuse.org
- Fix License tag
* Fri Dec 10 2010 reddwarf@opensuse.org
- update to version 1.0.0
  * AO returns to active development
  * Added surround channel mapping API and capability
  * Update and test all drivers on modern installs
  * New config file options
  * Driver options may be specifid in config file
  * Support for MacosX < 1.5 dropped, driver moded to AUHAL
  * Build in WMM driver rather than using dlopen()
  * Added Roar Audio driver
  * Added OpenBSD SNDIO driver
  * Work around ESD non-4096 byte write bug
  * Work around aRts server crash bug
  * Workaround for VIA82xx click/crackle bugs under ALSA
  * Remove dead/unused drivers (solaris, alasa05, mmsound)
  * Numerous patches from multiple downstreams
- run spec-cleaner
- follow library packaging policy
- removed libao-pkgconfig.diff (fixed upstream)
- removed libao-configure.diff as suggested (#93877, reapply if
  needed)
- updated libao-alsa-fix.diff
- add libao-missing_headers.diff
* Fri Dec 18 2009 jengelh@medozas.de
- enable parallel build
* Mon Apr 28 2008 tiwai@suse.de
- fixed dependency in *.pc (bnc#384168)
- removed obsolete run_ldconfig macro
* Thu Aug  2 2007 tiwai@suse.de
- updated to version 0.8.7:
  * obsolete alsa device renamed to alsa05
  * the 'alsa' device now uses the 0.9/1.0 API
  * ALSA driver fixes
- updated to version 0.8.8:
  * New win32 driver
  * Few fixes and changes in autotools and configuration files.
* Mon Apr 16 2007 tiwai@suse.de
- follow library packaging policy
  * move docs to devel package
  * remove *.la files
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jul  7 2005 tiwai@suse.de
- remove -fsigned-char (#93877)
- fixed Requires of devel subpackage.
* Wed Apr 13 2005 tiwai@suse.de
- added audiofile-devel to neededforbuild.
* Mon Feb  7 2005 tiwai@suse.de
- fixed the buffer allocation of ALSA plugin.
* Fri Jan 21 2005 tiwai@suse.de
- updated to version 0.8.6.
* Wed Nov 24 2004 tiwai@suse.de
- updated to version 0.8.5.
* Sun Apr 11 2004 aj@suse.de
- Does not need kdelibs3.
* Mon Feb  9 2004 tiwai@suse.de
- fixed builds on s390/s390x.
* Wed Jan 21 2004 tiwai@suse.de
- fixed quoting in m4 files.
* Fri Jan  9 2004 adrian@suse.de
- add %%run_ldconfig to %%postun
* Mon Oct  6 2003 ro@suse.de
- added glib2, glib2-devel to neededforbuild (arts)
* Wed Jul 23 2003 uli@suse.de
- no ALSA on s390x
- esound available on s390*
* Sun Jun  1 2003 ro@suse.de
- remove unpackaged files from buildroot
* Tue Jul 23 2002 tiwai@suse.de
- fixed m4 file for lib64.
- provides the backward compatible m4 file.
* Mon Jul 22 2002 tiwai@suse.de
- updated to version 0.8.3.
- clean up the spec file.
- added %%run_ldconfig.
* Mon May  6 2002 meissner@suse.de
- %%_lib fixes
* Tue Mar 12 2002 tiwai@suse.de
- added ao directory to the file list.
* Thu Feb 14 2002 ro@suse.de
- changed neededforbuild <kdelibs3-artsd> to <arts arts-devel>
* Tue Feb  5 2002 tiwai@suse.de
- fixed alsa09 plugin.  now it should work well on SB Live, too.
* Tue Jan 22 2002 ro@suse.de
- changed neededforbuild <kdelibs-artsd> to <kdelibs3-artsd>
* Fri Jan  4 2002 tiwai@suse.de
- updated to 0.8.2.
  sync with cvs 2002.01.04.
* Tue Dec  4 2001 tiwai@suse.de
- fixed filelist.
- sync with cvs 2001.12.04.
* Mon Dec  3 2001 tiwai@suse.de
- Enabled support for ALSA 0.9.0.
* Wed Oct 24 2001 tiwai@suse.de
- sync with cvs 20011024.  version 0.8.1.
  + ALSA 0.9.x support
  + ver.2 plugins added
- removed Requires to libao from devel & arts.
* Mon Aug 13 2001 tiwai@suse.de
- updated to 1.0rc2 from cvs 20010813.
* Fri Aug  3 2001 tiwai@suse.de
- added kdelibs-arts to needeforbuild.
- fixed build on s390.
* Thu Jun  7 2001 iwai@suse.de
- fixed build with the recent libtool.
* Wed Mar 21 2001 tiwai@suse.de
- added alsa plugin.
- added arts plugin.  provided as a separate package, libao-arts.
* Mon Feb 26 2001 tiwai@suse.de
- Updated to ver.0.6.0.
* Wed Jan 31 2001 tiwai@suse.de
- Initial version: 0.5.0
